ML4Chem
===========

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ml4chem.svg)
[![Build Status](https://travis-ci.com/muammar/ml4chem.svg?branch=master)](https://travis-ci.com/muammar/ml4chem)


**ML4Chem** is machine learning for chemistry.

This package is written in Python 3, and intends to offer modern and rich
features to perform machine learning workflows for chemical physics.

A list of features and methods are shown below.

- Atom-centered Neural Networks, and Kernel Ridge Regression for the prediction
  of total energies.
- PyTorch backend.
- GPU support.
- ASE interface.
- Completely modular. You can use any part of this package in your project.
- Free software <3. No secrets! Pull requests and additions are more than
  welcome!
- Good documentation (I hope!).
- Explicit and idiomatic: `ml4chem.get_me_a_coffee()`.
- Distributed training in a data parallelism paradigm (mini-batches).
- Scalability and distributed computations are powered by Dask <3.
- Real-time tools to track status of your computations.
- [Messagepack serialization](https://msgpack.org/index.html).


## Dask dashboard
![](https://raw.githubusercontent.com/muammar/ml4chem/master/docs/source/_static/dask_dashboard.png)

Note: This package is under development.
